/*	$Id: CallID.h 2 2005-11-11 21:32:03Z faxguy $ */
/*
 * Copyright (c) 2004 iFAX Solutions Inc.
 * HylaFAX is a trademark of Silicon Graphics
 *
 * Permission to use, copy, modify, distribute, and sell this software and 
 * its documentation for any purpose is hereby granted without fee, provided
 * that (i) the above copyright notices and this permission notice appear in
 * all copies of the software and related documentation, and (ii) the names of
 * Sam Leffler and Silicon Graphics may not be used in any advertising or
 * publicity relating to the software without the specific, prior written
 * permission of Sam Leffler and Silicon Graphics.
 * 
 * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
 * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
 * 
 * IN NO EVENT SHALL SAM LEFFLER OR SILICON GRAPHICS BE LIABLE FOR
 * ANY SPECIAL, INCIDENTAL, INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND,
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER OR NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF 
 * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE 
 * OF THIS SOFTWARE.
 */
#ifndef _CallID_
#define	_CallID_

#include "StrArray.h"

class CallID : public fxObj {
public:
    fxStrArray	_id;		// file containing data

    CallID (int howmany = 0);
    ~CallID (void);

    void operator= (const CallID&);
    void resize(int i);

    size_t makeString(fxStr&);

    fxStr& operator [](int i);
    const char* id (int i) const;
    int length (int i) const;

    bool isEmpty (void) const;

    size_t size(void) const;

    static const u_int NUMBER;	//=0;
    static const u_int NAME;	//=1;

};

#endif /* _CallID_ */
