/*
 * Copyright (c) 1990-1996 Sam Leffler
 * Copyright (c) 1991-1996 Silicon Graphics, Inc.
 * HylaFAX is a trademark of Silicon Graphics
 *
 * Permission to use, copy, modify, distribute, and sell this software and 
 * its documentation for any purpose is hereby granted without fee, provided
 * that (i) the above copyright notices and this permission notice appear in
 * all copies of the software and related documentation, and (ii) the names of
 * Sam Leffler and Silicon Graphics may not be used in any advertising or
 * publicity relating to the software without the specific, prior written
 * permission of Sam Leffler and Silicon Graphics.
 * 
 * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
 * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
 * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
 * 
 * IN NO EVENT SHALL SAM LEFFLER OR SILICON GRAPHICS BE LIABLE FOR
 * ANY SPECIAL, INCIDENTAL, INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND,
 * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
 * WHETHER OR NOT ADVISED OF THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF 
 * LIABILITY, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE 
 * OF THIS SOFTWARE.
 */
#ifndef _FaxHostID_
#define	_FaxHostID_
/*
 * HylaFAX host ID substructure.
 */
#include "Str.h"
#include "Array.h"

struct FaxHostID {
    fxStr	id;		// numeric host id
    fxStr	host;		// hostname or address
    fxStr	user;		// administrative username
    fxStr	pass;		// user-level password
    fxStr	adminpw;	// admin-levl password

    FaxHostID();
    FaxHostID(const fxStr& i, const fxStr& h, const fxStr& u, const fxStr& p, const fxStr& a);
    FaxHostID(const FaxHostID& other);
    ~FaxHostID();

    int compare(FaxHostID const *a) const;	// XXX needed for array
};
fxDECLARE_ObjArray(FaxHostIDArray, FaxHostID)
#endif /* _FaxItem_ */
